/**
 * Utils - Tag
 */
import { isObjectStrict } from '../isObject/isObject';
import { isStringStrict } from '../isString/isString';
import { isArrayStrict } from '../isArray/isArray';
/**
 * Easier access to tag info
 *
 * @type {import('./tagTypes').Tag}
 */
const tag = {
    get(obj, id) {
        if (!isObjectStrict(obj) || !isStringStrict(id)) {
            return;
        }
        const tags = obj.metadata?.tags;
        if (!isArrayStrict(tags)) {
            return;
        }
        const tagInfo = {
            id: '',
            name: ''
        };
        tags.find((tag) => {
            if (!isObjectStrict(tag)) {
                return false;
            }
            const tagId = tag.id;
            if (tagId === id) {
                tagInfo.id = tagId;
                tagInfo.name = isStringStrict(tag.name) ? tag.name : '';
                return true;
            }
            return false;
        });
        return tagInfo;
    },
    exists(obj, id) {
        const res = tag.get(obj, id);
        return res !== undefined;
    }
};
/* Exports */
export { tag };
